# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/ray/protobuf/gcs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as src_dot_ray_dot_protobuf_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='src/ray/protobuf/gcs.proto',
  package='ray.rpc',
  syntax='proto3',
  serialized_options=_b('\n\030io.ray.runtime.generated'),
  serialized_pb=_b('\n\x1asrc/ray/protobuf/gcs.proto\x12\x07ray.rpc\x1a\x1dsrc/ray/protobuf/common.proto\"m\n\x08GcsEntry\x12\x37\n\x0b\x63hange_mode\x18\x01 \x01(\x0e\x32\x16.ray.rpc.GcsChangeModeR\nchangeMode\x12\x0e\n\x02id\x18\x02 \x01(\x0cR\x02id\x12\x18\n\x07\x65ntries\x18\x03 \x03(\x0cR\x07\x65ntries\"+\n\x0fObjectTableData\x12\x18\n\x07manager\x18\x01 \x01(\x0cR\x07manager\"\x8a\x01\n\x16TaskReconstructionData\x12\x17\n\x07task_id\x18\x01 \x01(\x0cR\x06taskId\x12/\n\x13num_reconstructions\x18\x02 \x01(\x04R\x12numReconstructions\x12&\n\x0fnode_manager_id\x18\x03 \x01(\x0cR\rnodeManagerId\"2\n\rTaskTableData\x12!\n\x04task\x18\x01 \x01(\x0b\x32\r.ray.rpc.TaskR\x04task\"\xb2\x05\n\x0e\x41\x63torTableData\x12\x19\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cR\x07\x61\x63torId\x12\x1b\n\tparent_id\x18\x02 \x01(\x0cR\x08parentId\x12\x42\n\x1e\x61\x63tor_creation_dummy_object_id\x18\x03 \x01(\x0cR\x1a\x61\x63torCreationDummyObjectId\x12\x15\n\x06job_id\x18\x04 \x01(\x0cR\x05jobId\x12\x38\n\x05state\x18\x06 \x01(\x0e\x32\".ray.rpc.ActorTableData.ActorStateR\x05state\x12!\n\x0cmax_restarts\x18\x07 \x01(\x03R\x0bmaxRestarts\x12!\n\x0cnum_restarts\x18\x08 \x01(\x04R\x0bnumRestarts\x12*\n\x07\x61\x64\x64ress\x18\t \x01(\x0b\x32\x10.ray.rpc.AddressR\x07\x61\x64\x64ress\x12\x35\n\rowner_address\x18\n \x01(\x0b\x32\x10.ray.rpc.AddressR\x0cownerAddress\x12\x1f\n\x0bis_detached\x18\x0b \x01(\x08R\nisDetached\x12\x12\n\x04name\x18\x0c \x01(\tR\x04name\x12\x1c\n\ttimestamp\x18\r \x01(\x01R\ttimestamp\x12.\n\ttask_spec\x18\x0e \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\x12\x44\n\x10resource_mapping\x18\x0f \x03(\x0b\x32\x19.ray.rpc.ResourceMapEntryR\x0fresourceMapping\"a\n\nActorState\x12\x18\n\x14\x44\x45PENDENCIES_UNREADY\x10\x00\x12\x14\n\x10PENDING_CREATION\x10\x01\x12\t\n\x05\x41LIVE\x10\x02\x12\x0e\n\nRESTARTING\x10\x03\x12\x08\n\x04\x44\x45\x41\x44\x10\x04\"~\n\x0e\x45rrorTableData\x12\x15\n\x06job_id\x18\x01 \x01(\x0cR\x05jobId\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\x12\x1c\n\ttimestamp\x18\x04 \x01(\x01R\ttimestamp\"\x82\x04\n\x17PlacementGroupTableData\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12)\n\x07\x62undles\x18\x03 \x03(\x0b\x32\x0f.ray.rpc.BundleR\x07\x62undles\x12\x36\n\x08strategy\x18\x04 \x01(\x0e\x32\x1a.ray.rpc.PlacementStrategyR\x08strategy\x12J\n\x05state\x18\x05 \x01(\x0e\x32\x34.ray.rpc.PlacementGroupTableData.PlacementGroupStateR\x05state\x12$\n\x0e\x63reator_job_id\x18\x06 \x01(\x0cR\x0c\x63reatorJobId\x12(\n\x10\x63reator_actor_id\x18\x07 \x01(\x0cR\x0e\x63reatorActorId\x12(\n\x10\x63reator_job_dead\x18\x08 \x01(\x08R\x0e\x63reatorJobDead\x12,\n\x12\x63reator_actor_dead\x18\t \x01(\x08R\x10\x63reatorActorDead\"N\n\x13PlacementGroupState\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x12\x10\n\x0cRESCHEDULING\x10\x03\"\x9d\x01\n\x0cScheduleData\x12L\n\rschedule_plan\x18\x01 \x03(\x0b\x32\'.ray.rpc.ScheduleData.SchedulePlanEntryR\x0cschedulePlan\x1a?\n\x11SchedulePlanEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\xdc\x02\n\x10ProfileTableData\x12%\n\x0e\x63omponent_type\x18\x01 \x01(\tR\rcomponentType\x12!\n\x0c\x63omponent_id\x18\x02 \x01(\x0cR\x0b\x63omponentId\x12&\n\x0fnode_ip_address\x18\x03 \x01(\tR\rnodeIpAddress\x12M\n\x0eprofile_events\x18\x04 \x03(\x0b\x32&.ray.rpc.ProfileTableData.ProfileEventR\rprofileEvents\x1a\x86\x01\n\x0cProfileEvent\x12\x1d\n\nevent_type\x18\x01 \x01(\tR\teventType\x12\x1d\n\nstart_time\x18\x02 \x01(\x01R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x03 \x01(\x01R\x07\x65ndTime\x12\x1d\n\nextra_data\x18\x04 \x01(\tR\textraData\"@\n\x11ResourceTableData\x12+\n\x11resource_capacity\x18\x01 \x01(\x01R\x10resourceCapacity\"\xda\x01\n\x12\x41vailableResources\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12\x64\n\x13resources_available\x18\x02 \x03(\x0b\x32\x33.ray.rpc.AvailableResources.ResourcesAvailableEntryR\x12resourcesAvailable\x1a\x45\n\x17ResourcesAvailableEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xfb\x03\n\x0bGcsNodeInfo\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12\x30\n\x14node_manager_address\x18\x02 \x01(\tR\x12nodeManagerAddress\x12,\n\x12raylet_socket_name\x18\x03 \x01(\tR\x10rayletSocketName\x12\x37\n\x18object_store_socket_name\x18\x04 \x01(\tR\x15objectStoreSocketName\x12*\n\x11node_manager_port\x18\x05 \x01(\x05R\x0fnodeManagerPort\x12.\n\x13object_manager_port\x18\x06 \x01(\x05R\x11objectManagerPort\x12\x37\n\x05state\x18\x07 \x01(\x0e\x32!.ray.rpc.GcsNodeInfo.GcsNodeStateR\x05state\x12\x32\n\x15node_manager_hostname\x18\x08 \x01(\tR\x13nodeManagerHostname\x12.\n\x13metrics_export_port\x18\t \x01(\x05R\x11metricsExportPort\x12\x1c\n\ttimestamp\x18\n \x01(\x03R\ttimestamp\"#\n\x0cGcsNodeState\x12\t\n\x05\x41LIVE\x10\x00\x12\x08\n\x04\x44\x45\x41\x44\x10\x01\"\xa7\x02\n\x0eResourceDemand\x12\x38\n\x05shape\x18\x01 \x03(\x0b\x32\".ray.rpc.ResourceDemand.ShapeEntryR\x05shape\x12\x39\n\x19num_ready_requests_queued\x18\x02 \x01(\x04R\x16numReadyRequestsQueued\x12\x43\n\x1enum_infeasible_requests_queued\x18\x03 \x01(\x04R\x1bnumInfeasibleRequestsQueued\x12!\n\x0c\x62\x61\x63klog_size\x18\x04 \x01(\x03R\x0b\x62\x61\x63klogSize\x1a\x38\n\nShapeEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"R\n\x0cResourceLoad\x12\x42\n\x10resource_demands\x18\x01 \x03(\x0b\x32\x17.ray.rpc.ResourceDemandR\x0fresourceDemands\"h\n\x12PlacementGroupLoad\x12R\n\x14placement_group_data\x18\x01 \x03(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x12placementGroupData\"\xf6\x05\n\x12HeartbeatTableData\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12\x64\n\x13resources_available\x18\x02 \x03(\x0b\x32\x33.ray.rpc.HeartbeatTableData.ResourcesAvailableEntryR\x12resourcesAvailable\x12>\n\x1bresources_available_changed\x18\x03 \x01(\x08R\x19resourcesAvailableChanged\x12X\n\x0fresources_total\x18\x04 \x03(\x0b\x32/.ray.rpc.HeartbeatTableData.ResourcesTotalEntryR\x0eresourcesTotal\x12R\n\rresource_load\x18\x05 \x03(\x0b\x32-.ray.rpc.HeartbeatTableData.ResourceLoadEntryR\x0cresourceLoad\x12\x32\n\x15resource_load_changed\x18\x06 \x01(\x08R\x13resourceLoadChanged\x12J\n\x16resource_load_by_shape\x18\x07 \x01(\x0b\x32\x15.ray.rpc.ResourceLoadR\x13resourceLoadByShape\x12(\n\x10should_global_gc\x18\x08 \x01(\x08R\x0eshouldGlobalGc\x1a\x45\n\x17ResourcesAvailableEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\x41\n\x13ResourcesTotalEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a?\n\x11ResourceLoadEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xe2\x05\n\rResourcesData\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12_\n\x13resources_available\x18\x02 \x03(\x0b\x32..ray.rpc.ResourcesData.ResourcesAvailableEntryR\x12resourcesAvailable\x12>\n\x1bresources_available_changed\x18\x03 \x01(\x08R\x19resourcesAvailableChanged\x12S\n\x0fresources_total\x18\x04 \x03(\x0b\x32*.ray.rpc.ResourcesData.ResourcesTotalEntryR\x0eresourcesTotal\x12M\n\rresource_load\x18\x05 \x03(\x0b\x32(.ray.rpc.ResourcesData.ResourceLoadEntryR\x0cresourceLoad\x12\x32\n\x15resource_load_changed\x18\x06 \x01(\x08R\x13resourceLoadChanged\x12J\n\x16resource_load_by_shape\x18\x07 \x01(\x0b\x32\x15.ray.rpc.ResourceLoadR\x13resourceLoadByShape\x12(\n\x10should_global_gc\x18\x08 \x01(\x08R\x0eshouldGlobalGc\x1a\x45\n\x17ResourcesAvailableEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\x41\n\x13ResourcesTotalEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a?\n\x11ResourceLoadEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xe7\x01\n\x17HeartbeatBatchTableData\x12\x31\n\x05\x62\x61tch\x18\x01 \x03(\x0b\x32\x1b.ray.rpc.HeartbeatTableDataR\x05\x62\x61tch\x12J\n\x16resource_load_by_shape\x18\x02 \x01(\x0b\x32\x15.ray.rpc.ResourceLoadR\x13resourceLoadByShape\x12M\n\x14placement_group_load\x18\x03 \x01(\x0b\x32\x1b.ray.rpc.PlacementGroupLoadR\x12placementGroupLoad\"\x8b\x01\n\rTaskLeaseData\x12\x17\n\x07task_id\x18\x01 \x01(\x0cR\x06taskId\x12&\n\x0fnode_manager_id\x18\x02 \x01(\x0cR\rnodeManagerId\x12\x1f\n\x0b\x61\x63quired_at\x18\x03 \x01(\x04R\nacquiredAt\x12\x18\n\x07timeout\x18\x04 \x01(\x04R\x07timeout\"\x96\x02\n\tJobConfig\x12@\n\nworker_env\x18\x01 \x03(\x0b\x32!.ray.rpc.JobConfig.WorkerEnvEntryR\tworkerEnv\x12>\n\x1cnum_java_workers_per_process\x18\x02 \x01(\rR\x18numJavaWorkersPerProcess\x12\x1f\n\x0bjvm_options\x18\x03 \x03(\tR\njvmOptions\x12(\n\x10\x63ode_search_path\x18\x04 \x03(\tR\x0e\x63odeSearchPath\x1a<\n\x0eWorkerEnvEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd3\x01\n\x0cJobTableData\x12\x15\n\x06job_id\x18\x01 \x01(\x0cR\x05jobId\x12\x17\n\x07is_dead\x18\x02 \x01(\x08R\x06isDead\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\x12*\n\x11\x64river_ip_address\x18\x04 \x01(\tR\x0f\x64riverIpAddress\x12\x1d\n\ndriver_pid\x18\x05 \x01(\x03R\tdriverPid\x12*\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x12.ray.rpc.JobConfigR\x06\x63onfig\"\xfa\x02\n\x0fWorkerTableData\x12\x19\n\x08is_alive\x18\x01 \x01(\x08R\x07isAlive\x12\x37\n\x0eworker_address\x18\x02 \x01(\x0b\x32\x10.ray.rpc.AddressR\rworkerAddress\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\x12\x35\n\x16intentional_disconnect\x18\x04 \x01(\x08R\x15intentionalDisconnect\x12\x34\n\x0bworker_type\x18\x05 \x01(\x0e\x32\x13.ray.rpc.WorkerTypeR\nworkerType\x12I\n\x0bworker_info\x18\x06 \x03(\x0b\x32(.ray.rpc.WorkerTableData.WorkerInfoEntryR\nworkerInfo\x1a=\n\x0fWorkerInfoEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\x9a\x01\n\x0bResourceMap\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32\x1f.ray.rpc.ResourceMap.ItemsEntryR\x05items\x1aT\n\nItemsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ray.rpc.ResourceTableDataR\x05value:\x02\x38\x01\"\x84\x01\n\x0cStoredConfig\x12\x39\n\x06\x63onfig\x18\x01 \x03(\x0b\x32!.ray.rpc.StoredConfig.ConfigEntryR\x06\x63onfig\x1a\x39\n\x0b\x43onfigEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8a\x01\n\x12ObjectLocationInfo\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\x12\x36\n\tlocations\x18\x02 \x03(\x0b\x32\x18.ray.rpc.ObjectTableDataR\tlocations\x12\x1f\n\x0bspilled_url\x18\x03 \x01(\tR\nspilledUrl\"g\n\x14ObjectLocationChange\x12\x15\n\x06is_add\x18\x01 \x01(\x08R\x05isAdd\x12\x17\n\x07node_id\x18\x02 \x01(\x0cR\x06nodeId\x12\x1f\n\x0bspilled_url\x18\x03 \x01(\tR\nspilledUrl\"\xff\x01\n\x12NodeResourceChange\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12^\n\x11updated_resources\x18\x02 \x03(\x0b\x32\x31.ray.rpc.NodeResourceChange.UpdatedResourcesEntryR\x10updatedResources\x12+\n\x11\x64\x65leted_resources\x18\x03 \x03(\tR\x10\x64\x65letedResources\x1a\x43\n\x15UpdatedResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"3\n\rPubSubMessage\x12\x0e\n\x02id\x18\x01 \x01(\x0cR\x02id\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta*\xec\x02\n\x0bTablePrefix\x12\x14\n\x10TABLE_PREFIX_MIN\x10\x00\x12\n\n\x06UNUSED\x10\x01\x12\x08\n\x04TASK\x10\x02\x12\x0f\n\x0bRAYLET_TASK\x10\x03\x12\x08\n\x04NODE\x10\x04\x12\n\n\x06OBJECT\x10\x05\x12\t\n\x05\x41\x43TOR\x10\x06\x12\x0c\n\x08\x46UNCTION\x10\x07\x12\x17\n\x13TASK_RECONSTRUCTION\x10\x08\x12\r\n\tHEARTBEAT\x10\t\x12\x13\n\x0fHEARTBEAT_BATCH\x10\n\x12\x07\n\x03JOB\x10\x0b\x12\x0b\n\x07PROFILE\x10\x0c\x12\x0e\n\nTASK_LEASE\x10\r\x12\x11\n\rNODE_RESOURCE\x10\x10\x12\x10\n\x0c\x44IRECT_ACTOR\x10\x11\x12\x0b\n\x07WORKERS\x10\x12\x12\x13\n\x0fINTERNAL_CONFIG\x10\x1d\x12\x14\n\x10TABLE_PREFIX_MAX\x10\x14\x12\x1c\n\x18PLACEMENT_GROUP_SCHEDULE\x10\x15\x12\x13\n\x0fPLACEMENT_GROUP\x10\x16*\xcf\x02\n\x0bTablePubsub\x12\x14\n\x10TABLE_PUBSUB_MIN\x10\x00\x12\x0e\n\nNO_PUBLISH\x10\x01\x12\x0f\n\x0bTASK_PUBSUB\x10\x02\x12\x16\n\x12RAYLET_TASK_PUBSUB\x10\x03\x12\x0f\n\x0bNODE_PUBSUB\x10\x04\x12\x11\n\rOBJECT_PUBSUB\x10\x05\x12\x10\n\x0c\x41\x43TOR_PUBSUB\x10\x06\x12\x14\n\x10HEARTBEAT_PUBSUB\x10\x07\x12\x1a\n\x16HEARTBEAT_BATCH_PUBSUB\x10\x08\x12\x15\n\x11TASK_LEASE_PUBSUB\x10\t\x12\x0e\n\nJOB_PUBSUB\x10\n\x12\x18\n\x14NODE_RESOURCE_PUBSUB\x10\x0b\x12\x17\n\x13\x44IRECT_ACTOR_PUBSUB\x10\x0c\x12\x19\n\x15WORKER_FAILURE_PUBSUB\x10\r\x12\x14\n\x10TABLE_PUBSUB_MAX\x10\x0e*.\n\rGcsChangeMode\x12\x11\n\rAPPEND_OR_ADD\x10\x00\x12\n\n\x06REMOVE\x10\x01\x42\x1a\n\x18io.ray.runtime.generatedb\x06proto3')
  ,
  dependencies=[src_dot_ray_dot_protobuf_dot_common__pb2.DESCRIPTOR,])

_TABLEPREFIX = _descriptor.EnumDescriptor(
  name='TablePrefix',
  full_name='ray.rpc.TablePrefix',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TABLE_PREFIX_MIN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNUSED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TASK', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAYLET_TASK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NODE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OBJECT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTOR', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FUNCTION', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TASK_RECONSTRUCTION', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT_BATCH', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROFILE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TASK_LEASE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NODE_RESOURCE', index=14, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIRECT_ACTOR', index=15, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKERS', index=16, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_CONFIG', index=17, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TABLE_PREFIX_MAX', index=18, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_GROUP_SCHEDULE', index=19, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_GROUP', index=20, number=22,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7157,
  serialized_end=7521,
)
_sym_db.RegisterEnumDescriptor(_TABLEPREFIX)

TablePrefix = enum_type_wrapper.EnumTypeWrapper(_TABLEPREFIX)
_TABLEPUBSUB = _descriptor.EnumDescriptor(
  name='TablePubsub',
  full_name='ray.rpc.TablePubsub',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TABLE_PUBSUB_MIN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_PUBLISH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TASK_PUBSUB', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAYLET_TASK_PUBSUB', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NODE_PUBSUB', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_PUBSUB', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTOR_PUBSUB', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT_PUBSUB', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT_BATCH_PUBSUB', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TASK_LEASE_PUBSUB', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB_PUBSUB', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NODE_RESOURCE_PUBSUB', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIRECT_ACTOR_PUBSUB', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKER_FAILURE_PUBSUB', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TABLE_PUBSUB_MAX', index=14, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7524,
  serialized_end=7859,
)
_sym_db.RegisterEnumDescriptor(_TABLEPUBSUB)

TablePubsub = enum_type_wrapper.EnumTypeWrapper(_TABLEPUBSUB)
_GCSCHANGEMODE = _descriptor.EnumDescriptor(
  name='GcsChangeMode',
  full_name='ray.rpc.GcsChangeMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='APPEND_OR_ADD', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7861,
  serialized_end=7907,
)
_sym_db.RegisterEnumDescriptor(_GCSCHANGEMODE)

GcsChangeMode = enum_type_wrapper.EnumTypeWrapper(_GCSCHANGEMODE)
TABLE_PREFIX_MIN = 0
UNUSED = 1
TASK = 2
RAYLET_TASK = 3
NODE = 4
OBJECT = 5
ACTOR = 6
FUNCTION = 7
TASK_RECONSTRUCTION = 8
HEARTBEAT = 9
HEARTBEAT_BATCH = 10
JOB = 11
PROFILE = 12
TASK_LEASE = 13
NODE_RESOURCE = 16
DIRECT_ACTOR = 17
WORKERS = 18
INTERNAL_CONFIG = 29
TABLE_PREFIX_MAX = 20
PLACEMENT_GROUP_SCHEDULE = 21
PLACEMENT_GROUP = 22
TABLE_PUBSUB_MIN = 0
NO_PUBLISH = 1
TASK_PUBSUB = 2
RAYLET_TASK_PUBSUB = 3
NODE_PUBSUB = 4
OBJECT_PUBSUB = 5
ACTOR_PUBSUB = 6
HEARTBEAT_PUBSUB = 7
HEARTBEAT_BATCH_PUBSUB = 8
TASK_LEASE_PUBSUB = 9
JOB_PUBSUB = 10
NODE_RESOURCE_PUBSUB = 11
DIRECT_ACTOR_PUBSUB = 12
WORKER_FAILURE_PUBSUB = 13
TABLE_PUBSUB_MAX = 14
APPEND_OR_ADD = 0
REMOVE = 1


_ACTORTABLEDATA_ACTORSTATE = _descriptor.EnumDescriptor(
  name='ActorState',
  full_name='ray.rpc.ActorTableData.ActorState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEPENDENCIES_UNREADY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING_CREATION', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALIVE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESTARTING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1013,
  serialized_end=1110,
)
_sym_db.RegisterEnumDescriptor(_ACTORTABLEDATA_ACTORSTATE)

_PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE = _descriptor.EnumDescriptor(
  name='PlacementGroupState',
  full_name='ray.rpc.PlacementGroupTableData.PlacementGroupState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESCHEDULING', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1677,
  serialized_end=1755,
)
_sym_db.RegisterEnumDescriptor(_PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE)

_GCSNODEINFO_GCSNODESTATE = _descriptor.EnumDescriptor(
  name='GcsNodeState',
  full_name='ray.rpc.GcsNodeInfo.GcsNodeState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3028,
  serialized_end=3063,
)
_sym_db.RegisterEnumDescriptor(_GCSNODEINFO_GCSNODESTATE)


_GCSENTRY = _descriptor.Descriptor(
  name='GcsEntry',
  full_name='ray.rpc.GcsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_mode', full_name='ray.rpc.GcsEntry.change_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='changeMode', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='ray.rpc.GcsEntry.id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='ray.rpc.GcsEntry.entries', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entries', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=179,
)


_OBJECTTABLEDATA = _descriptor.Descriptor(
  name='ObjectTableData',
  full_name='ray.rpc.ObjectTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='manager', full_name='ray.rpc.ObjectTableData.manager', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='manager', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=224,
)


_TASKRECONSTRUCTIONDATA = _descriptor.Descriptor(
  name='TaskReconstructionData',
  full_name='ray.rpc.TaskReconstructionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.TaskReconstructionData.task_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_reconstructions', full_name='ray.rpc.TaskReconstructionData.num_reconstructions', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numReconstructions', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_manager_id', full_name='ray.rpc.TaskReconstructionData.node_manager_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=365,
)


_TASKTABLEDATA = _descriptor.Descriptor(
  name='TaskTableData',
  full_name='ray.rpc.TaskTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='ray.rpc.TaskTableData.task', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='task', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=417,
)


_ACTORTABLEDATA = _descriptor.Descriptor(
  name='ActorTableData',
  full_name='ray.rpc.ActorTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.ActorTableData.actor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='ray.rpc.ActorTableData.parent_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parentId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actor_creation_dummy_object_id', full_name='ray.rpc.ActorTableData.actor_creation_dummy_object_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorCreationDummyObjectId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.ActorTableData.job_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='ray.rpc.ActorTableData.state', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='state', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_restarts', full_name='ray.rpc.ActorTableData.max_restarts', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxRestarts', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_restarts', full_name='ray.rpc.ActorTableData.num_restarts', index=6,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numRestarts', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='ray.rpc.ActorTableData.address', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_address', full_name='ray.rpc.ActorTableData.owner_address', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ownerAddress', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_detached', full_name='ray.rpc.ActorTableData.is_detached', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isDetached', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.ActorTableData.name', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.ActorTableData.timestamp', index=11,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_spec', full_name='ray.rpc.ActorTableData.task_spec', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskSpec', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_mapping', full_name='ray.rpc.ActorTableData.resource_mapping', index=13,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceMapping', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACTORTABLEDATA_ACTORSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=1110,
)


_ERRORTABLEDATA = _descriptor.Descriptor(
  name='ErrorTableData',
  full_name='ray.rpc.ErrorTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.ErrorTableData.job_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='ray.rpc.ErrorTableData.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='ray.rpc.ErrorTableData.error_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errorMessage', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.ErrorTableData.timestamp', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1238,
)


_PLACEMENTGROUPTABLEDATA = _descriptor.Descriptor(
  name='PlacementGroupTableData',
  full_name='ray.rpc.PlacementGroupTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.PlacementGroupTableData.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.PlacementGroupTableData.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bundles', full_name='ray.rpc.PlacementGroupTableData.bundles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bundles', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='ray.rpc.PlacementGroupTableData.strategy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='strategy', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='ray.rpc.PlacementGroupTableData.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='state', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator_job_id', full_name='ray.rpc.PlacementGroupTableData.creator_job_id', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorJobId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator_actor_id', full_name='ray.rpc.PlacementGroupTableData.creator_actor_id', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorActorId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator_job_dead', full_name='ray.rpc.PlacementGroupTableData.creator_job_dead', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorJobDead', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator_actor_dead', full_name='ray.rpc.PlacementGroupTableData.creator_actor_dead', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorActorDead', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1755,
)


_SCHEDULEDATA_SCHEDULEPLANENTRY = _descriptor.Descriptor(
  name='SchedulePlanEntry',
  full_name='ray.rpc.ScheduleData.SchedulePlanEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ScheduleData.SchedulePlanEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ScheduleData.SchedulePlanEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1915,
)

_SCHEDULEDATA = _descriptor.Descriptor(
  name='ScheduleData',
  full_name='ray.rpc.ScheduleData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule_plan', full_name='ray.rpc.ScheduleData.schedule_plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schedulePlan', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SCHEDULEDATA_SCHEDULEPLANENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1758,
  serialized_end=1915,
)


_PROFILETABLEDATA_PROFILEEVENT = _descriptor.Descriptor(
  name='ProfileEvent',
  full_name='ray.rpc.ProfileTableData.ProfileEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_type', full_name='ray.rpc.ProfileTableData.ProfileEvent.event_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='ray.rpc.ProfileTableData.ProfileEvent.start_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTime', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='ray.rpc.ProfileTableData.ProfileEvent.end_time', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endTime', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_data', full_name='ray.rpc.ProfileTableData.ProfileEvent.extra_data', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extraData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2132,
  serialized_end=2266,
)

_PROFILETABLEDATA = _descriptor.Descriptor(
  name='ProfileTableData',
  full_name='ray.rpc.ProfileTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component_type', full_name='ray.rpc.ProfileTableData.component_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='componentType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component_id', full_name='ray.rpc.ProfileTableData.component_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='componentId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_ip_address', full_name='ray.rpc.ProfileTableData.node_ip_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeIpAddress', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_events', full_name='ray.rpc.ProfileTableData.profile_events', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='profileEvents', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROFILETABLEDATA_PROFILEEVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=2266,
)


_RESOURCETABLEDATA = _descriptor.Descriptor(
  name='ResourceTableData',
  full_name='ray.rpc.ResourceTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_capacity', full_name='ray.rpc.ResourceTableData.resource_capacity', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceCapacity', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2268,
  serialized_end=2332,
)


_AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY = _descriptor.Descriptor(
  name='ResourcesAvailableEntry',
  full_name='ray.rpc.AvailableResources.ResourcesAvailableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.AvailableResources.ResourcesAvailableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.AvailableResources.ResourcesAvailableEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2484,
  serialized_end=2553,
)

_AVAILABLERESOURCES = _descriptor.Descriptor(
  name='AvailableResources',
  full_name='ray.rpc.AvailableResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.AvailableResources.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_available', full_name='ray.rpc.AvailableResources.resources_available', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesAvailable', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2335,
  serialized_end=2553,
)


_GCSNODEINFO = _descriptor.Descriptor(
  name='GcsNodeInfo',
  full_name='ray.rpc.GcsNodeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.GcsNodeInfo.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_manager_address', full_name='ray.rpc.GcsNodeInfo.node_manager_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerAddress', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raylet_socket_name', full_name='ray.rpc.GcsNodeInfo.raylet_socket_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayletSocketName', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_store_socket_name', full_name='ray.rpc.GcsNodeInfo.object_store_socket_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectStoreSocketName', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_manager_port', full_name='ray.rpc.GcsNodeInfo.node_manager_port', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerPort', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_manager_port', full_name='ray.rpc.GcsNodeInfo.object_manager_port', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectManagerPort', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='ray.rpc.GcsNodeInfo.state', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='state', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_manager_hostname', full_name='ray.rpc.GcsNodeInfo.node_manager_hostname', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerHostname', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics_export_port', full_name='ray.rpc.GcsNodeInfo.metrics_export_port', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metricsExportPort', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.GcsNodeInfo.timestamp', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GCSNODEINFO_GCSNODESTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2556,
  serialized_end=3063,
)


_RESOURCEDEMAND_SHAPEENTRY = _descriptor.Descriptor(
  name='ShapeEntry',
  full_name='ray.rpc.ResourceDemand.ShapeEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourceDemand.ShapeEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourceDemand.ShapeEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3305,
  serialized_end=3361,
)

_RESOURCEDEMAND = _descriptor.Descriptor(
  name='ResourceDemand',
  full_name='ray.rpc.ResourceDemand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='ray.rpc.ResourceDemand.shape', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='shape', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_ready_requests_queued', full_name='ray.rpc.ResourceDemand.num_ready_requests_queued', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numReadyRequestsQueued', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_infeasible_requests_queued', full_name='ray.rpc.ResourceDemand.num_infeasible_requests_queued', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numInfeasibleRequestsQueued', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backlog_size', full_name='ray.rpc.ResourceDemand.backlog_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='backlogSize', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEDEMAND_SHAPEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3066,
  serialized_end=3361,
)


_RESOURCELOAD = _descriptor.Descriptor(
  name='ResourceLoad',
  full_name='ray.rpc.ResourceLoad',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_demands', full_name='ray.rpc.ResourceLoad.resource_demands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceDemands', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3363,
  serialized_end=3445,
)


_PLACEMENTGROUPLOAD = _descriptor.Descriptor(
  name='PlacementGroupLoad',
  full_name='ray.rpc.PlacementGroupLoad',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_data', full_name='ray.rpc.PlacementGroupLoad.placement_group_data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3447,
  serialized_end=3551,
)


_HEARTBEATTABLEDATA_RESOURCESAVAILABLEENTRY = _descriptor.Descriptor(
  name='ResourcesAvailableEntry',
  full_name='ray.rpc.HeartbeatTableData.ResourcesAvailableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.HeartbeatTableData.ResourcesAvailableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.HeartbeatTableData.ResourcesAvailableEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2484,
  serialized_end=2553,
)

_HEARTBEATTABLEDATA_RESOURCESTOTALENTRY = _descriptor.Descriptor(
  name='ResourcesTotalEntry',
  full_name='ray.rpc.HeartbeatTableData.ResourcesTotalEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.HeartbeatTableData.ResourcesTotalEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.HeartbeatTableData.ResourcesTotalEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4182,
  serialized_end=4247,
)

_HEARTBEATTABLEDATA_RESOURCELOADENTRY = _descriptor.Descriptor(
  name='ResourceLoadEntry',
  full_name='ray.rpc.HeartbeatTableData.ResourceLoadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.HeartbeatTableData.ResourceLoadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.HeartbeatTableData.ResourceLoadEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4249,
  serialized_end=4312,
)

_HEARTBEATTABLEDATA = _descriptor.Descriptor(
  name='HeartbeatTableData',
  full_name='ray.rpc.HeartbeatTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.HeartbeatTableData.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_available', full_name='ray.rpc.HeartbeatTableData.resources_available', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesAvailable', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_available_changed', full_name='ray.rpc.HeartbeatTableData.resources_available_changed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesAvailableChanged', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_total', full_name='ray.rpc.HeartbeatTableData.resources_total', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesTotal', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_load', full_name='ray.rpc.HeartbeatTableData.resource_load', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoad', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_load_changed', full_name='ray.rpc.HeartbeatTableData.resource_load_changed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoadChanged', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_load_by_shape', full_name='ray.rpc.HeartbeatTableData.resource_load_by_shape', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoadByShape', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_global_gc', full_name='ray.rpc.HeartbeatTableData.should_global_gc', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='shouldGlobalGc', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HEARTBEATTABLEDATA_RESOURCESAVAILABLEENTRY, _HEARTBEATTABLEDATA_RESOURCESTOTALENTRY, _HEARTBEATTABLEDATA_RESOURCELOADENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3554,
  serialized_end=4312,
)


_RESOURCESDATA_RESOURCESAVAILABLEENTRY = _descriptor.Descriptor(
  name='ResourcesAvailableEntry',
  full_name='ray.rpc.ResourcesData.ResourcesAvailableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourcesData.ResourcesAvailableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourcesData.ResourcesAvailableEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2484,
  serialized_end=2553,
)

_RESOURCESDATA_RESOURCESTOTALENTRY = _descriptor.Descriptor(
  name='ResourcesTotalEntry',
  full_name='ray.rpc.ResourcesData.ResourcesTotalEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourcesData.ResourcesTotalEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourcesData.ResourcesTotalEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4182,
  serialized_end=4247,
)

_RESOURCESDATA_RESOURCELOADENTRY = _descriptor.Descriptor(
  name='ResourceLoadEntry',
  full_name='ray.rpc.ResourcesData.ResourceLoadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourcesData.ResourceLoadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourcesData.ResourceLoadEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4249,
  serialized_end=4312,
)

_RESOURCESDATA = _descriptor.Descriptor(
  name='ResourcesData',
  full_name='ray.rpc.ResourcesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.ResourcesData.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_available', full_name='ray.rpc.ResourcesData.resources_available', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesAvailable', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_available_changed', full_name='ray.rpc.ResourcesData.resources_available_changed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesAvailableChanged', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_total', full_name='ray.rpc.ResourcesData.resources_total', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesTotal', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_load', full_name='ray.rpc.ResourcesData.resource_load', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoad', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_load_changed', full_name='ray.rpc.ResourcesData.resource_load_changed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoadChanged', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_load_by_shape', full_name='ray.rpc.ResourcesData.resource_load_by_shape', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoadByShape', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_global_gc', full_name='ray.rpc.ResourcesData.should_global_gc', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='shouldGlobalGc', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCESDATA_RESOURCESAVAILABLEENTRY, _RESOURCESDATA_RESOURCESTOTALENTRY, _RESOURCESDATA_RESOURCELOADENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4315,
  serialized_end=5053,
)


_HEARTBEATBATCHTABLEDATA = _descriptor.Descriptor(
  name='HeartbeatBatchTableData',
  full_name='ray.rpc.HeartbeatBatchTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch', full_name='ray.rpc.HeartbeatBatchTableData.batch', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batch', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_load_by_shape', full_name='ray.rpc.HeartbeatBatchTableData.resource_load_by_shape', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceLoadByShape', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement_group_load', full_name='ray.rpc.HeartbeatBatchTableData.placement_group_load', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupLoad', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5056,
  serialized_end=5287,
)


_TASKLEASEDATA = _descriptor.Descriptor(
  name='TaskLeaseData',
  full_name='ray.rpc.TaskLeaseData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.TaskLeaseData.task_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_manager_id', full_name='ray.rpc.TaskLeaseData.node_manager_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeManagerId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acquired_at', full_name='ray.rpc.TaskLeaseData.acquired_at', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='acquiredAt', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='ray.rpc.TaskLeaseData.timeout', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeout', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5290,
  serialized_end=5429,
)


_JOBCONFIG_WORKERENVENTRY = _descriptor.Descriptor(
  name='WorkerEnvEntry',
  full_name='ray.rpc.JobConfig.WorkerEnvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.JobConfig.WorkerEnvEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.JobConfig.WorkerEnvEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5650,
  serialized_end=5710,
)

_JOBCONFIG = _descriptor.Descriptor(
  name='JobConfig',
  full_name='ray.rpc.JobConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_env', full_name='ray.rpc.JobConfig.worker_env', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerEnv', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_java_workers_per_process', full_name='ray.rpc.JobConfig.num_java_workers_per_process', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numJavaWorkersPerProcess', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jvm_options', full_name='ray.rpc.JobConfig.jvm_options', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jvmOptions', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code_search_path', full_name='ray.rpc.JobConfig.code_search_path', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='codeSearchPath', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_JOBCONFIG_WORKERENVENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5432,
  serialized_end=5710,
)


_JOBTABLEDATA = _descriptor.Descriptor(
  name='JobTableData',
  full_name='ray.rpc.JobTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.JobTableData.job_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_dead', full_name='ray.rpc.JobTableData.is_dead', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isDead', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.JobTableData.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='driver_ip_address', full_name='ray.rpc.JobTableData.driver_ip_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='driverIpAddress', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='driver_pid', full_name='ray.rpc.JobTableData.driver_pid', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='driverPid', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='ray.rpc.JobTableData.config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='config', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5713,
  serialized_end=5924,
)


_WORKERTABLEDATA_WORKERINFOENTRY = _descriptor.Descriptor(
  name='WorkerInfoEntry',
  full_name='ray.rpc.WorkerTableData.WorkerInfoEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.WorkerTableData.WorkerInfoEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.WorkerTableData.WorkerInfoEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6244,
  serialized_end=6305,
)

_WORKERTABLEDATA = _descriptor.Descriptor(
  name='WorkerTableData',
  full_name='ray.rpc.WorkerTableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_alive', full_name='ray.rpc.WorkerTableData.is_alive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isAlive', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_address', full_name='ray.rpc.WorkerTableData.worker_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerAddress', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.WorkerTableData.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intentional_disconnect', full_name='ray.rpc.WorkerTableData.intentional_disconnect', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='intentionalDisconnect', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_type', full_name='ray.rpc.WorkerTableData.worker_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_info', full_name='ray.rpc.WorkerTableData.worker_info', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerInfo', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WORKERTABLEDATA_WORKERINFOENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5927,
  serialized_end=6305,
)


_RESOURCEMAP_ITEMSENTRY = _descriptor.Descriptor(
  name='ItemsEntry',
  full_name='ray.rpc.ResourceMap.ItemsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ResourceMap.ItemsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ResourceMap.ItemsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6378,
  serialized_end=6462,
)

_RESOURCEMAP = _descriptor.Descriptor(
  name='ResourceMap',
  full_name='ray.rpc.ResourceMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='ray.rpc.ResourceMap.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='items', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEMAP_ITEMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6308,
  serialized_end=6462,
)


_STOREDCONFIG_CONFIGENTRY = _descriptor.Descriptor(
  name='ConfigEntry',
  full_name='ray.rpc.StoredConfig.ConfigEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.StoredConfig.ConfigEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.StoredConfig.ConfigEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6540,
  serialized_end=6597,
)

_STOREDCONFIG = _descriptor.Descriptor(
  name='StoredConfig',
  full_name='ray.rpc.StoredConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='ray.rpc.StoredConfig.config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='config', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STOREDCONFIG_CONFIGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6465,
  serialized_end=6597,
)


_OBJECTLOCATIONINFO = _descriptor.Descriptor(
  name='ObjectLocationInfo',
  full_name='ray.rpc.ObjectLocationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.ObjectLocationInfo.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locations', full_name='ray.rpc.ObjectLocationInfo.locations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='locations', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spilled_url', full_name='ray.rpc.ObjectLocationInfo.spilled_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledUrl', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6600,
  serialized_end=6738,
)


_OBJECTLOCATIONCHANGE = _descriptor.Descriptor(
  name='ObjectLocationChange',
  full_name='ray.rpc.ObjectLocationChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_add', full_name='ray.rpc.ObjectLocationChange.is_add', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isAdd', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.ObjectLocationChange.node_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spilled_url', full_name='ray.rpc.ObjectLocationChange.spilled_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledUrl', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6740,
  serialized_end=6843,
)


_NODERESOURCECHANGE_UPDATEDRESOURCESENTRY = _descriptor.Descriptor(
  name='UpdatedResourcesEntry',
  full_name='ray.rpc.NodeResourceChange.UpdatedResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.NodeResourceChange.UpdatedResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.NodeResourceChange.UpdatedResourcesEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7034,
  serialized_end=7101,
)

_NODERESOURCECHANGE = _descriptor.Descriptor(
  name='NodeResourceChange',
  full_name='ray.rpc.NodeResourceChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.NodeResourceChange.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_resources', full_name='ray.rpc.NodeResourceChange.updated_resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updatedResources', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted_resources', full_name='ray.rpc.NodeResourceChange.deleted_resources', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deletedResources', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_NODERESOURCECHANGE_UPDATEDRESOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6846,
  serialized_end=7101,
)


_PUBSUBMESSAGE = _descriptor.Descriptor(
  name='PubSubMessage',
  full_name='ray.rpc.PubSubMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ray.rpc.PubSubMessage.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.PubSubMessage.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7103,
  serialized_end=7154,
)

_GCSENTRY.fields_by_name['change_mode'].enum_type = _GCSCHANGEMODE
_TASKTABLEDATA.fields_by_name['task'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._TASK
_ACTORTABLEDATA.fields_by_name['state'].enum_type = _ACTORTABLEDATA_ACTORSTATE
_ACTORTABLEDATA.fields_by_name['address'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._ADDRESS
_ACTORTABLEDATA.fields_by_name['owner_address'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._ADDRESS
_ACTORTABLEDATA.fields_by_name['task_spec'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._TASKSPEC
_ACTORTABLEDATA.fields_by_name['resource_mapping'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._RESOURCEMAPENTRY
_ACTORTABLEDATA_ACTORSTATE.containing_type = _ACTORTABLEDATA
_PLACEMENTGROUPTABLEDATA.fields_by_name['bundles'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._BUNDLE
_PLACEMENTGROUPTABLEDATA.fields_by_name['strategy'].enum_type = src_dot_ray_dot_protobuf_dot_common__pb2._PLACEMENTSTRATEGY
_PLACEMENTGROUPTABLEDATA.fields_by_name['state'].enum_type = _PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE
_PLACEMENTGROUPTABLEDATA_PLACEMENTGROUPSTATE.containing_type = _PLACEMENTGROUPTABLEDATA
_SCHEDULEDATA_SCHEDULEPLANENTRY.containing_type = _SCHEDULEDATA
_SCHEDULEDATA.fields_by_name['schedule_plan'].message_type = _SCHEDULEDATA_SCHEDULEPLANENTRY
_PROFILETABLEDATA_PROFILEEVENT.containing_type = _PROFILETABLEDATA
_PROFILETABLEDATA.fields_by_name['profile_events'].message_type = _PROFILETABLEDATA_PROFILEEVENT
_AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY.containing_type = _AVAILABLERESOURCES
_AVAILABLERESOURCES.fields_by_name['resources_available'].message_type = _AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY
_GCSNODEINFO.fields_by_name['state'].enum_type = _GCSNODEINFO_GCSNODESTATE
_GCSNODEINFO_GCSNODESTATE.containing_type = _GCSNODEINFO
_RESOURCEDEMAND_SHAPEENTRY.containing_type = _RESOURCEDEMAND
_RESOURCEDEMAND.fields_by_name['shape'].message_type = _RESOURCEDEMAND_SHAPEENTRY
_RESOURCELOAD.fields_by_name['resource_demands'].message_type = _RESOURCEDEMAND
_PLACEMENTGROUPLOAD.fields_by_name['placement_group_data'].message_type = _PLACEMENTGROUPTABLEDATA
_HEARTBEATTABLEDATA_RESOURCESAVAILABLEENTRY.containing_type = _HEARTBEATTABLEDATA
_HEARTBEATTABLEDATA_RESOURCESTOTALENTRY.containing_type = _HEARTBEATTABLEDATA
_HEARTBEATTABLEDATA_RESOURCELOADENTRY.containing_type = _HEARTBEATTABLEDATA
_HEARTBEATTABLEDATA.fields_by_name['resources_available'].message_type = _HEARTBEATTABLEDATA_RESOURCESAVAILABLEENTRY
_HEARTBEATTABLEDATA.fields_by_name['resources_total'].message_type = _HEARTBEATTABLEDATA_RESOURCESTOTALENTRY
_HEARTBEATTABLEDATA.fields_by_name['resource_load'].message_type = _HEARTBEATTABLEDATA_RESOURCELOADENTRY
_HEARTBEATTABLEDATA.fields_by_name['resource_load_by_shape'].message_type = _RESOURCELOAD
_RESOURCESDATA_RESOURCESAVAILABLEENTRY.containing_type = _RESOURCESDATA
_RESOURCESDATA_RESOURCESTOTALENTRY.containing_type = _RESOURCESDATA
_RESOURCESDATA_RESOURCELOADENTRY.containing_type = _RESOURCESDATA
_RESOURCESDATA.fields_by_name['resources_available'].message_type = _RESOURCESDATA_RESOURCESAVAILABLEENTRY
_RESOURCESDATA.fields_by_name['resources_total'].message_type = _RESOURCESDATA_RESOURCESTOTALENTRY
_RESOURCESDATA.fields_by_name['resource_load'].message_type = _RESOURCESDATA_RESOURCELOADENTRY
_RESOURCESDATA.fields_by_name['resource_load_by_shape'].message_type = _RESOURCELOAD
_HEARTBEATBATCHTABLEDATA.fields_by_name['batch'].message_type = _HEARTBEATTABLEDATA
_HEARTBEATBATCHTABLEDATA.fields_by_name['resource_load_by_shape'].message_type = _RESOURCELOAD
_HEARTBEATBATCHTABLEDATA.fields_by_name['placement_group_load'].message_type = _PLACEMENTGROUPLOAD
_JOBCONFIG_WORKERENVENTRY.containing_type = _JOBCONFIG
_JOBCONFIG.fields_by_name['worker_env'].message_type = _JOBCONFIG_WORKERENVENTRY
_JOBTABLEDATA.fields_by_name['config'].message_type = _JOBCONFIG
_WORKERTABLEDATA_WORKERINFOENTRY.containing_type = _WORKERTABLEDATA
_WORKERTABLEDATA.fields_by_name['worker_address'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._ADDRESS
_WORKERTABLEDATA.fields_by_name['worker_type'].enum_type = src_dot_ray_dot_protobuf_dot_common__pb2._WORKERTYPE
_WORKERTABLEDATA.fields_by_name['worker_info'].message_type = _WORKERTABLEDATA_WORKERINFOENTRY
_RESOURCEMAP_ITEMSENTRY.fields_by_name['value'].message_type = _RESOURCETABLEDATA
_RESOURCEMAP_ITEMSENTRY.containing_type = _RESOURCEMAP
_RESOURCEMAP.fields_by_name['items'].message_type = _RESOURCEMAP_ITEMSENTRY
_STOREDCONFIG_CONFIGENTRY.containing_type = _STOREDCONFIG
_STOREDCONFIG.fields_by_name['config'].message_type = _STOREDCONFIG_CONFIGENTRY
_OBJECTLOCATIONINFO.fields_by_name['locations'].message_type = _OBJECTTABLEDATA
_NODERESOURCECHANGE_UPDATEDRESOURCESENTRY.containing_type = _NODERESOURCECHANGE
_NODERESOURCECHANGE.fields_by_name['updated_resources'].message_type = _NODERESOURCECHANGE_UPDATEDRESOURCESENTRY
DESCRIPTOR.message_types_by_name['GcsEntry'] = _GCSENTRY
DESCRIPTOR.message_types_by_name['ObjectTableData'] = _OBJECTTABLEDATA
DESCRIPTOR.message_types_by_name['TaskReconstructionData'] = _TASKRECONSTRUCTIONDATA
DESCRIPTOR.message_types_by_name['TaskTableData'] = _TASKTABLEDATA
DESCRIPTOR.message_types_by_name['ActorTableData'] = _ACTORTABLEDATA
DESCRIPTOR.message_types_by_name['ErrorTableData'] = _ERRORTABLEDATA
DESCRIPTOR.message_types_by_name['PlacementGroupTableData'] = _PLACEMENTGROUPTABLEDATA
DESCRIPTOR.message_types_by_name['ScheduleData'] = _SCHEDULEDATA
DESCRIPTOR.message_types_by_name['ProfileTableData'] = _PROFILETABLEDATA
DESCRIPTOR.message_types_by_name['ResourceTableData'] = _RESOURCETABLEDATA
DESCRIPTOR.message_types_by_name['AvailableResources'] = _AVAILABLERESOURCES
DESCRIPTOR.message_types_by_name['GcsNodeInfo'] = _GCSNODEINFO
DESCRIPTOR.message_types_by_name['ResourceDemand'] = _RESOURCEDEMAND
DESCRIPTOR.message_types_by_name['ResourceLoad'] = _RESOURCELOAD
DESCRIPTOR.message_types_by_name['PlacementGroupLoad'] = _PLACEMENTGROUPLOAD
DESCRIPTOR.message_types_by_name['HeartbeatTableData'] = _HEARTBEATTABLEDATA
DESCRIPTOR.message_types_by_name['ResourcesData'] = _RESOURCESDATA
DESCRIPTOR.message_types_by_name['HeartbeatBatchTableData'] = _HEARTBEATBATCHTABLEDATA
DESCRIPTOR.message_types_by_name['TaskLeaseData'] = _TASKLEASEDATA
DESCRIPTOR.message_types_by_name['JobConfig'] = _JOBCONFIG
DESCRIPTOR.message_types_by_name['JobTableData'] = _JOBTABLEDATA
DESCRIPTOR.message_types_by_name['WorkerTableData'] = _WORKERTABLEDATA
DESCRIPTOR.message_types_by_name['ResourceMap'] = _RESOURCEMAP
DESCRIPTOR.message_types_by_name['StoredConfig'] = _STOREDCONFIG
DESCRIPTOR.message_types_by_name['ObjectLocationInfo'] = _OBJECTLOCATIONINFO
DESCRIPTOR.message_types_by_name['ObjectLocationChange'] = _OBJECTLOCATIONCHANGE
DESCRIPTOR.message_types_by_name['NodeResourceChange'] = _NODERESOURCECHANGE
DESCRIPTOR.message_types_by_name['PubSubMessage'] = _PUBSUBMESSAGE
DESCRIPTOR.enum_types_by_name['TablePrefix'] = _TABLEPREFIX
DESCRIPTOR.enum_types_by_name['TablePubsub'] = _TABLEPUBSUB
DESCRIPTOR.enum_types_by_name['GcsChangeMode'] = _GCSCHANGEMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GcsEntry = _reflection.GeneratedProtocolMessageType('GcsEntry', (_message.Message,), {
  'DESCRIPTOR' : _GCSENTRY,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsEntry)
  })
_sym_db.RegisterMessage(GcsEntry)

ObjectTableData = _reflection.GeneratedProtocolMessageType('ObjectTableData', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectTableData)
  })
_sym_db.RegisterMessage(ObjectTableData)

TaskReconstructionData = _reflection.GeneratedProtocolMessageType('TaskReconstructionData', (_message.Message,), {
  'DESCRIPTOR' : _TASKRECONSTRUCTIONDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskReconstructionData)
  })
_sym_db.RegisterMessage(TaskReconstructionData)

TaskTableData = _reflection.GeneratedProtocolMessageType('TaskTableData', (_message.Message,), {
  'DESCRIPTOR' : _TASKTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskTableData)
  })
_sym_db.RegisterMessage(TaskTableData)

ActorTableData = _reflection.GeneratedProtocolMessageType('ActorTableData', (_message.Message,), {
  'DESCRIPTOR' : _ACTORTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ActorTableData)
  })
_sym_db.RegisterMessage(ActorTableData)

ErrorTableData = _reflection.GeneratedProtocolMessageType('ErrorTableData', (_message.Message,), {
  'DESCRIPTOR' : _ERRORTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ErrorTableData)
  })
_sym_db.RegisterMessage(ErrorTableData)

PlacementGroupTableData = _reflection.GeneratedProtocolMessageType('PlacementGroupTableData', (_message.Message,), {
  'DESCRIPTOR' : _PLACEMENTGROUPTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PlacementGroupTableData)
  })
_sym_db.RegisterMessage(PlacementGroupTableData)

ScheduleData = _reflection.GeneratedProtocolMessageType('ScheduleData', (_message.Message,), {

  'SchedulePlanEntry' : _reflection.GeneratedProtocolMessageType('SchedulePlanEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEDULEDATA_SCHEDULEPLANENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ScheduleData.SchedulePlanEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEDULEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ScheduleData)
  })
_sym_db.RegisterMessage(ScheduleData)
_sym_db.RegisterMessage(ScheduleData.SchedulePlanEntry)

ProfileTableData = _reflection.GeneratedProtocolMessageType('ProfileTableData', (_message.Message,), {

  'ProfileEvent' : _reflection.GeneratedProtocolMessageType('ProfileEvent', (_message.Message,), {
    'DESCRIPTOR' : _PROFILETABLEDATA_PROFILEEVENT,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ProfileTableData.ProfileEvent)
    })
  ,
  'DESCRIPTOR' : _PROFILETABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ProfileTableData)
  })
_sym_db.RegisterMessage(ProfileTableData)
_sym_db.RegisterMessage(ProfileTableData.ProfileEvent)

ResourceTableData = _reflection.GeneratedProtocolMessageType('ResourceTableData', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceTableData)
  })
_sym_db.RegisterMessage(ResourceTableData)

AvailableResources = _reflection.GeneratedProtocolMessageType('AvailableResources', (_message.Message,), {

  'ResourcesAvailableEntry' : _reflection.GeneratedProtocolMessageType('ResourcesAvailableEntry', (_message.Message,), {
    'DESCRIPTOR' : _AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.AvailableResources.ResourcesAvailableEntry)
    })
  ,
  'DESCRIPTOR' : _AVAILABLERESOURCES,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AvailableResources)
  })
_sym_db.RegisterMessage(AvailableResources)
_sym_db.RegisterMessage(AvailableResources.ResourcesAvailableEntry)

GcsNodeInfo = _reflection.GeneratedProtocolMessageType('GcsNodeInfo', (_message.Message,), {
  'DESCRIPTOR' : _GCSNODEINFO,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsNodeInfo)
  })
_sym_db.RegisterMessage(GcsNodeInfo)

ResourceDemand = _reflection.GeneratedProtocolMessageType('ResourceDemand', (_message.Message,), {

  'ShapeEntry' : _reflection.GeneratedProtocolMessageType('ShapeEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEDEMAND_SHAPEENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourceDemand.ShapeEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCEDEMAND,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceDemand)
  })
_sym_db.RegisterMessage(ResourceDemand)
_sym_db.RegisterMessage(ResourceDemand.ShapeEntry)

ResourceLoad = _reflection.GeneratedProtocolMessageType('ResourceLoad', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCELOAD,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceLoad)
  })
_sym_db.RegisterMessage(ResourceLoad)

PlacementGroupLoad = _reflection.GeneratedProtocolMessageType('PlacementGroupLoad', (_message.Message,), {
  'DESCRIPTOR' : _PLACEMENTGROUPLOAD,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PlacementGroupLoad)
  })
_sym_db.RegisterMessage(PlacementGroupLoad)

HeartbeatTableData = _reflection.GeneratedProtocolMessageType('HeartbeatTableData', (_message.Message,), {

  'ResourcesAvailableEntry' : _reflection.GeneratedProtocolMessageType('ResourcesAvailableEntry', (_message.Message,), {
    'DESCRIPTOR' : _HEARTBEATTABLEDATA_RESOURCESAVAILABLEENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.HeartbeatTableData.ResourcesAvailableEntry)
    })
  ,

  'ResourcesTotalEntry' : _reflection.GeneratedProtocolMessageType('ResourcesTotalEntry', (_message.Message,), {
    'DESCRIPTOR' : _HEARTBEATTABLEDATA_RESOURCESTOTALENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.HeartbeatTableData.ResourcesTotalEntry)
    })
  ,

  'ResourceLoadEntry' : _reflection.GeneratedProtocolMessageType('ResourceLoadEntry', (_message.Message,), {
    'DESCRIPTOR' : _HEARTBEATTABLEDATA_RESOURCELOADENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.HeartbeatTableData.ResourceLoadEntry)
    })
  ,
  'DESCRIPTOR' : _HEARTBEATTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.HeartbeatTableData)
  })
_sym_db.RegisterMessage(HeartbeatTableData)
_sym_db.RegisterMessage(HeartbeatTableData.ResourcesAvailableEntry)
_sym_db.RegisterMessage(HeartbeatTableData.ResourcesTotalEntry)
_sym_db.RegisterMessage(HeartbeatTableData.ResourceLoadEntry)

ResourcesData = _reflection.GeneratedProtocolMessageType('ResourcesData', (_message.Message,), {

  'ResourcesAvailableEntry' : _reflection.GeneratedProtocolMessageType('ResourcesAvailableEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCESDATA_RESOURCESAVAILABLEENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData.ResourcesAvailableEntry)
    })
  ,

  'ResourcesTotalEntry' : _reflection.GeneratedProtocolMessageType('ResourcesTotalEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCESDATA_RESOURCESTOTALENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData.ResourcesTotalEntry)
    })
  ,

  'ResourceLoadEntry' : _reflection.GeneratedProtocolMessageType('ResourceLoadEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCESDATA_RESOURCELOADENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData.ResourceLoadEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCESDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourcesData)
  })
_sym_db.RegisterMessage(ResourcesData)
_sym_db.RegisterMessage(ResourcesData.ResourcesAvailableEntry)
_sym_db.RegisterMessage(ResourcesData.ResourcesTotalEntry)
_sym_db.RegisterMessage(ResourcesData.ResourceLoadEntry)

HeartbeatBatchTableData = _reflection.GeneratedProtocolMessageType('HeartbeatBatchTableData', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATBATCHTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.HeartbeatBatchTableData)
  })
_sym_db.RegisterMessage(HeartbeatBatchTableData)

TaskLeaseData = _reflection.GeneratedProtocolMessageType('TaskLeaseData', (_message.Message,), {
  'DESCRIPTOR' : _TASKLEASEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskLeaseData)
  })
_sym_db.RegisterMessage(TaskLeaseData)

JobConfig = _reflection.GeneratedProtocolMessageType('JobConfig', (_message.Message,), {

  'WorkerEnvEntry' : _reflection.GeneratedProtocolMessageType('WorkerEnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBCONFIG_WORKERENVENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.JobConfig.WorkerEnvEntry)
    })
  ,
  'DESCRIPTOR' : _JOBCONFIG,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.JobConfig)
  })
_sym_db.RegisterMessage(JobConfig)
_sym_db.RegisterMessage(JobConfig.WorkerEnvEntry)

JobTableData = _reflection.GeneratedProtocolMessageType('JobTableData', (_message.Message,), {
  'DESCRIPTOR' : _JOBTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.JobTableData)
  })
_sym_db.RegisterMessage(JobTableData)

WorkerTableData = _reflection.GeneratedProtocolMessageType('WorkerTableData', (_message.Message,), {

  'WorkerInfoEntry' : _reflection.GeneratedProtocolMessageType('WorkerInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKERTABLEDATA_WORKERINFOENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.WorkerTableData.WorkerInfoEntry)
    })
  ,
  'DESCRIPTOR' : _WORKERTABLEDATA,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WorkerTableData)
  })
_sym_db.RegisterMessage(WorkerTableData)
_sym_db.RegisterMessage(WorkerTableData.WorkerInfoEntry)

ResourceMap = _reflection.GeneratedProtocolMessageType('ResourceMap', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEMAP_ITEMSENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourceMap.ItemsEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCEMAP,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceMap)
  })
_sym_db.RegisterMessage(ResourceMap)
_sym_db.RegisterMessage(ResourceMap.ItemsEntry)

StoredConfig = _reflection.GeneratedProtocolMessageType('StoredConfig', (_message.Message,), {

  'ConfigEntry' : _reflection.GeneratedProtocolMessageType('ConfigEntry', (_message.Message,), {
    'DESCRIPTOR' : _STOREDCONFIG_CONFIGENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.StoredConfig.ConfigEntry)
    })
  ,
  'DESCRIPTOR' : _STOREDCONFIG,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.StoredConfig)
  })
_sym_db.RegisterMessage(StoredConfig)
_sym_db.RegisterMessage(StoredConfig.ConfigEntry)

ObjectLocationInfo = _reflection.GeneratedProtocolMessageType('ObjectLocationInfo', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTLOCATIONINFO,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectLocationInfo)
  })
_sym_db.RegisterMessage(ObjectLocationInfo)

ObjectLocationChange = _reflection.GeneratedProtocolMessageType('ObjectLocationChange', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTLOCATIONCHANGE,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectLocationChange)
  })
_sym_db.RegisterMessage(ObjectLocationChange)

NodeResourceChange = _reflection.GeneratedProtocolMessageType('NodeResourceChange', (_message.Message,), {

  'UpdatedResourcesEntry' : _reflection.GeneratedProtocolMessageType('UpdatedResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODERESOURCECHANGE_UPDATEDRESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.gcs_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.NodeResourceChange.UpdatedResourcesEntry)
    })
  ,
  'DESCRIPTOR' : _NODERESOURCECHANGE,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.NodeResourceChange)
  })
_sym_db.RegisterMessage(NodeResourceChange)
_sym_db.RegisterMessage(NodeResourceChange.UpdatedResourcesEntry)

PubSubMessage = _reflection.GeneratedProtocolMessageType('PubSubMessage', (_message.Message,), {
  'DESCRIPTOR' : _PUBSUBMESSAGE,
  '__module__' : 'src.ray.protobuf.gcs_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PubSubMessage)
  })
_sym_db.RegisterMessage(PubSubMessage)


DESCRIPTOR._options = None
_SCHEDULEDATA_SCHEDULEPLANENTRY._options = None
_AVAILABLERESOURCES_RESOURCESAVAILABLEENTRY._options = None
_RESOURCEDEMAND_SHAPEENTRY._options = None
_HEARTBEATTABLEDATA_RESOURCESAVAILABLEENTRY._options = None
_HEARTBEATTABLEDATA_RESOURCESTOTALENTRY._options = None
_HEARTBEATTABLEDATA_RESOURCELOADENTRY._options = None
_RESOURCESDATA_RESOURCESAVAILABLEENTRY._options = None
_RESOURCESDATA_RESOURCESTOTALENTRY._options = None
_RESOURCESDATA_RESOURCELOADENTRY._options = None
_JOBCONFIG_WORKERENVENTRY._options = None
_WORKERTABLEDATA_WORKERINFOENTRY._options = None
_RESOURCEMAP_ITEMSENTRY._options = None
_STOREDCONFIG_CONFIGENTRY._options = None
_NODERESOURCECHANGE_UPDATEDRESOURCESENTRY._options = None
# @@protoc_insertion_point(module_scope)
